svn commit: r310699 - head/sys/dev/sfxge/common

Andrew Rybchenko arybchik at FreeBSD.org
Wed Dec 28 13:28:45 UTC 2016


Author: arybchik
Date: Wed Dec 28 13:28:44 2016
New Revision: 310699
URL: https://svnweb.freebsd.org/changeset/base/310699

Log:
  sfxge(4): rename hunt_bist_* methods to ef10_bist_*
  
  Submitted by:   Mark Spender <mspender at solarflare.com>
  Sponsored by:   Solarflare Communications, Inc.
  MFC after:      2 days

Modified:
  head/sys/dev/sfxge/common/efx_phy.c
  head/sys/dev/sfxge/common/hunt_impl.h
  head/sys/dev/sfxge/common/hunt_phy.c

Modified: head/sys/dev/sfxge/common/efx_phy.c
==============================================================================
--- head/sys/dev/sfxge/common/efx_phy.c	Wed Dec 28 13:11:22 2016	(r310698)
+++ head/sys/dev/sfxge/common/efx_phy.c	Wed Dec 28 13:28:44 2016	(r310699)
@@ -65,11 +65,10 @@ static const efx_phy_ops_t	__efx_phy_ef1
 	ef10_phy_stats_update,		/* epo_stats_update */
 #endif	/* EFSYS_OPT_PHY_STATS */
 #if EFSYS_OPT_BIST
-	/* FIXME: Are these BIST methods appropriate for Medford? */
-	hunt_bist_enable_offline,	/* epo_bist_enable_offline */
-	hunt_bist_start,		/* epo_bist_start */
-	hunt_bist_poll,			/* epo_bist_poll */
-	hunt_bist_stop,			/* epo_bist_stop */
+	ef10_bist_enable_offline,	/* epo_bist_enable_offline */
+	ef10_bist_start,		/* epo_bist_start */
+	ef10_bist_poll,			/* epo_bist_poll */
+	ef10_bist_stop,			/* epo_bist_stop */
 #endif	/* EFSYS_OPT_BIST */
 };
 #endif	/* EFSYS_OPT_HUNTINGTON || EFSYS_OPT_MEDFORD */

Modified: head/sys/dev/sfxge/common/hunt_impl.h
==============================================================================
--- head/sys/dev/sfxge/common/hunt_impl.h	Wed Dec 28 13:11:22 2016	(r310698)
+++ head/sys/dev/sfxge/common/hunt_impl.h	Wed Dec 28 13:28:44 2016	(r310699)
@@ -75,16 +75,16 @@ hunt_board_cfg(
 #if EFSYS_OPT_BIST
 
 extern	__checkReturn		efx_rc_t
-hunt_bist_enable_offline(
+ef10_bist_enable_offline(
 	__in			efx_nic_t *enp);
 
 extern	__checkReturn		efx_rc_t
-hunt_bist_start(
+ef10_bist_start(
 	__in			efx_nic_t *enp,
 	__in			efx_bist_type_t type);
 
 extern	__checkReturn		efx_rc_t
-hunt_bist_poll(
+ef10_bist_poll(
 	__in			efx_nic_t *enp,
 	__in			efx_bist_type_t type,
 	__out			efx_bist_result_t *resultp,
@@ -95,7 +95,7 @@ hunt_bist_poll(
 	__in			size_t count);
 
 extern				void
-hunt_bist_stop(
+ef10_bist_stop(
 	__in			efx_nic_t *enp,
 	__in			efx_bist_type_t type);
 

Modified: head/sys/dev/sfxge/common/hunt_phy.c
==============================================================================
--- head/sys/dev/sfxge/common/hunt_phy.c	Wed Dec 28 13:11:22 2016	(r310698)
+++ head/sys/dev/sfxge/common/hunt_phy.c	Wed Dec 28 13:28:44 2016	(r310699)
@@ -39,7 +39,7 @@ __FBSDID("$FreeBSD$");
 #if EFSYS_OPT_BIST
 
 	__checkReturn		efx_rc_t
-hunt_bist_enable_offline(
+ef10_bist_enable_offline(
 	__in			efx_nic_t *enp)
 {
 	efx_rc_t rc;
@@ -56,7 +56,7 @@ fail1:
 }
 
 	__checkReturn		efx_rc_t
-hunt_bist_start(
+ef10_bist_start(
 	__in			efx_nic_t *enp,
 	__in			efx_bist_type_t type)
 {
@@ -74,7 +74,7 @@ fail1:
 }
 
 	__checkReturn		efx_rc_t
-hunt_bist_poll(
+ef10_bist_poll(
 	__in			efx_nic_t *enp,
 	__in			efx_bist_type_t type,
 	__out			efx_bist_result_t *resultp,
@@ -179,11 +179,11 @@ fail1:
 }
 
 			void
-hunt_bist_stop(
+ef10_bist_stop(
 	__in		efx_nic_t *enp,
 	__in		efx_bist_type_t type)
 {
 	/* There is no way to stop BIST on Huntinton. */
 	_NOTE(ARGUNUSED(enp, type))
 }
 
@@ -179,11 +179,11 @@ fail1:
 	__in		efx_bist_type_t type)
 {
-	/* There is no way to stop BIST on Huntinton. */
+	/* There is no way to stop BIST on EF10. */
 	_NOTE(ARGUNUSED(enp, type))
 }


More information about the svn-src-all mailing list